﻿using Connected.Annotations;
using Connected.Extensions;
using Connected.Utilities;
using Microsoft.AspNetCore.Components;

namespace Connected.Components;

public partial class Button : ButtonBase
{
	/// <summary>
	/// Child content of component.
	/// </summary>
	[Parameter]
	public RenderFragment? ChildContent { get; set; }

	private CssBuilder CompiledClassList
	{
		get
		{
			return new CssBuilder("button-root mud-button")
			.AddClass($"button-{Variant}")
			.AddClass($"button-{Variant}-{Color}")
			.AddClass($"button-{Variant}-size-{Size}")
			.AddClass($"ripple", !CanRipple)
			.AddClass($"elevation-{Elevation}")
			.AddClass(ClassList);
		}
	}

	/// <summary>
	/// A space separated list of class names, added on top of the default class list.
	/// </summary>
	[Parameter]
	public string? ClassList { get; set; }

	/// <summary>
	/// The color of the component. It supports the theme colors.
	/// </summary>
	[Parameter]
	public ThemeColor Color { get; set; } = ThemeColor.Default;

	/// <summary>
	/// The Size of the component.
	/// </summary>
	[Parameter]
	public Size Size { get; set; } = Size.Medium;

	/// <summary>
	/// The variant to use.
	/// </summary>
	[Parameter]
	public Variant Variant { get; set; } = Variant.Text;
}
